# This file has been generated


build_system = 'AppVeyor'
build_id = '35331745'
build_number = '550'
build_version = '1.0.550'
job_id = 'xpagku1jolu68p7v'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/stlib/build/job/xpagku1jolu68p7v'
